import setuptools


setuptools.setup(
    name="pcl2",
    version="0.0.2",
    author="author",
    author_email="author@example.com",
    description="A small example package",
    license="MIT",
    packages=["pcl2"]
)
